from enum import Enum

class AuthenticationParametersKeys(str, Enum):
    """Enumerator of the Authentication Parameter Keys."""
    API_KEY_CONFIGURATION_NAME = "api_key_configuration_name"
    API_KEY_HEADER_NAME = "api_key_header_name"
    API_KEY_PREFIX = "api_key_prefix"



from pydantic import Field
from typing import Optional, Literal
from .message_content_item_base import MessageContentItemBase
from .message_content_item_types import MessageContentItemTypes

class OpenAIImageFileMessageContentItem(MessageContentItemBase):
    """An OpenAI image file message content item."""

    type: Literal[MessageContentItemTypes.IMAGE_FILE] = MessageContentItemTypes.IMAGE_FILE
    file_id: Optional[str] = Field(None, alias="file_id")
    file_url: Optional[str] = Field(None, alias="file_url")



"""
Class Name: KnowledgeManagementCompletionRequest
Description: Encapsulates the metadata required to complete a knowledge management orchestration request.
"""
from typing import Optional
from .knowledge_management_agent import KnowledgeManagementAgent
from foundationallm.models.orchestration import CompletionRequestBase

class KnowledgeManagementCompletionRequest(CompletionRequestBase):
    """
    The completion request received from the Orchestration API.
    """    
    agent: Optional[KnowledgeManagementAgent] = None
    objects: dict = {}



from abc import ABC, abstractmethod
from typing import List
from foundationallm.config import Configuration, UserIdentity
from foundationallm.langchain.common import FoundationaLLMWorkflowBase
from foundationallm.models.agents import AgentTool, ExternalAgentWorkflow
from foundationallm.plugins import PluginManagerTypes

class WorkflowPluginManagerBase(ABC):
    """
    The base class for all workflow plugin managers.
    """
    def __init__(self):
        
        self.plugin_manager_type = PluginManagerTypes.WORKFLOWS

    @abstractmethod
    def create_workflow(self,
        workflow_config: ExternalAgentWorkflow,
        objects: dict,
        tools: List[AgentTool],
        user_identity: UserIdentity,
        config: Configuration) -> FoundationaLLMWorkflowBase:
        """
        Create a workflow instance based on the given configuration and tools.
        Parameters
            ----------
            workflow_config : ExternalAgentWorkflow
                The workflow assigned to the agent.
            objects : dict
                The exploded objects assigned from the agent.
            tools : List[AgentTool]
                The tools assigned to the agent.
            user_identity : UserIdentity
                The user identity of the user initiating the request.
            config : Configuration
                The application configuration for FoundationaLLM.
        """
        pass

    @abstractmethod
    def refresh_tools():
        pass



from pydantic import BaseModel, Field
from typing import Optional

class AttachmentProperties(BaseModel):
    """
    Properties of an attachment.
    """
    original_file_name: Optional[str] = Field(None, description="The original file name of the attachment.")
    content_type: Optional[str] = Field(None, description="The content/mime type of the attachment.")
    provider: Optional[str] = Field(None, description="The provider of the attachment.")
    provider_file_name: Optional[str] = Field(None, description="The provider's file name/URL of the attachment.")
    provider_storage_account_name: Optional[str] = Field(None, description="The storage account hosting the attachment.")



from pydantic import BaseModel, Field
from typing import Optional
from .message_content_item_types import MessageContentItemTypes
from foundationallm.models.constants import AgentCapabilityCategories

class MessageContentItemBase(BaseModel):
    """Base message content item model."""

    type: Optional[str] = Field(None, description="The type of message content item.")
    agent_capability_category: Optional[AgentCapabilityCategories] = Field(None, description="The category of capability assigned to the agent.")
    
    class Config:
        use_enum_values = True
        populate_by_name = True
        extra = "forbid"
